@@ -1,4 +1,4 @@
-/***************************************************************************
+/*****************f**********************************************************
                           kwappen.cpp  -  description
                              -------------------
     begin                : Sam Okt 20 14:11:56 CEST 2001
@@ -115,19 +115,25 @@ void Kwappen::eatblank()               // eat spaces (string)
 void Kwappen::start_turm()
 {
   char reihe, spalte;
-  for(spalte = 0; spalte <= 3; spalte++)     // clear columns
+  do                                         // loop avoids rows with same card color
   {
-    for(reihe = 0; reihe <= 11 ; reihe++)
+    for(spalte = 0; spalte <= 3; spalte++)   // clear columns
     {
-      turm[reihe][spalte] = 0; }
+      for(reihe = 0; reihe <= 11 ; reihe++)
+      {
+        turm[reihe][spalte] = 0;
+      }
     }
     for (spalte = 0; spalte <= 3; spalte++)  // create the 4 columns
     {
       turm_farbe(spalte);
     }
-    stein1 = random_color();                 // computer arms
-    sekunden = 0;                            // second counter to 0
-    timer->start(1000,false);                // start timer (1000 ms interval)
+    found = 0;
+    vier_shrink();                           // four row test
+  }while(found);
+  stein1 = random_color();                   // computer arms
+  sekunden = 0;                              // second counter to 0
+  timer->start(1000,false);                  // start timer (1000 ms interval)
 }
 
 void Kwappen::draw_turmset()                 // move selected stone
@@ -152,7 +158,7 @@ void Kwappen::draw_turmset()                 // move selected stone
 
 void Kwappen::set_computer()                 // add computer stone on column top
 {
-  int i;
+  char i;
   spalte1 = random_column();                 // random column
   i = 0;
   while (turm[i][spalte1] > 0) i++;
@@ -229,7 +235,7 @@ void Kwappen::turm_copy()
    }
 }
 
-void Kwappen::turm_shrinking()               // copy columns back
+void Kwappen::turm_shrinking()               // shrink columns
 {
   char j, reihe, spalte;
   for(spalte = 0; spalte <= 3; spalte++)
@@ -255,7 +261,7 @@ void Kwappen::turm_reduce()                      // tower shrink algorithm
     vier_shrink();                               // four row shrink
     column_shrink();                             // column shrink
     turm_shrinking();                            // shrink tower
-  }while(found == 1);
+  }while(found);
   status = 7;
   repaint();
 }
@@ -863,11 +869,12 @@ HighscoreEdit::HighscoreEdit(QWidget* parent, const char* name, WFlags f) : QDia
   setCaption("Highscore");
   highButton = new QPushButton(" Okay ",this);
   highButton->setGeometry(100,160,80,30);
-  connect(highButton, SIGNAL(clicked()),SLOT(getHighscore()));
   highscoreentry = new QLineEdit(this);
   highscoreentry->setGeometry(10,120,250,30);
   highscoreentry->setFont(QFont("courier", 14, QFont::Normal));
   strcpy(playerName,"Noname");
+  connect(highButton, SIGNAL(clicked()),SLOT(getHighscore()));
+  connect(highscoreentry, SIGNAL(returnPressed()),SLOT(getHighscore()));
 }
 
 Heraldry::Heraldry(QWidget* parent, const char* name, WFlags f) : QDialog(parent, name, TRUE, f)
